@@ -19,7 +19,7 @@ import uuid
 
 import requests
 from tempest import clients
-from tempest.common import cred_provider
+from tempest.common import credentials_factory as common_creds
 from tempest.common import dynamic_creds
 from tempest import config
 from tempest import test
@@ -334,7 +334,7 @@ class TestCase(test.BaseTestCase):
 
         # If no credentials are provided, the Manager will use those
         # in CONF.identity and generate an auth_provider from them
-        cls.creds = cred_provider.get_configured_credentials(
+        cls.creds = common_creds.get_configured_credentials(
             credential_type='identity_admin')
         mgr = clients.Manager(cls.creds)
         cls.client = MuranoClient(mgr.auth_provider)
@@ -405,8 +405,11 @@ class NegativeTestCase(TestCase):
 
         # If no credentials are provided, the Manager will use those
         # in CONF.identity and generate an auth_provider from them
+        admin_creds = common_creds.get_configured_credentials(
+            credential_type='identity_admin')
+
         cls.dynamic_creds = dynamic_creds.DynamicCredentialProvider(
-            'v2', name=cls.__name__)
+            identity_version='v2', name=cls.__name__, admin_creds=admin_creds)
         creds = cls.dynamic_creds.get_alt_creds()
         mgr = clients.Manager(credentials=creds)
         cls.alt_client = MuranoClient(mgr.auth_provider)
